==> markdownlint-0.0.8.tgz: package/test/inline-disable-enable.md <==
# Header

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable-->

hard	tab / space * in * emphasis / space ` in ` code

<!--MARKDOWNLINT-ENABLE -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!--  markdownlint-disable MD010-->

hard	tab / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-ENABLE  MD010  -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable MD010 MD038 -->

hard	tab / space * in * emphasis {MD037} / space ` in ` code

<!-- MARKDOWNLINT-enable  MD010  MD038  -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

before <!-- markdownlint-disable MD010 --> <!-- markdownlint-disable MD038 --> after

hard	tab / space * in * emphasis {MD037} / space ` in ` code

before<!-- markdownlint-enable MD010 --><!-- markdownlint-enable MD038 -->after

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable hard_tab code -->

hard	tab / space * in * emphasis {MD037} / space ` in ` code

<!-- markdownlint-enable whitespace -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

hard	tab {MD010} <!-- markdownlint-disable --> <!-- markdownlint-enable -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

hard	tab <!-- markdownlint-disable md010 -->
<!-- markdownlint-enable md010 -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-enable -->
hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}
<!-- markdownlint-disable -->
<!-- markdownlint-disable -->
hard	tab / space * in * emphasis / space ` in ` code
<!-- markdownlint-enable -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable NotATag MD038 -->
hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code
<!-- markdownlint-enable NotATag MD038 -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

embedded <b>{MD033}</b> HTML

==> markdownlint-0.4.1.tgz: package/test/inline-disable-enable.md <==
# Header

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable-->

hard	tab / space * in * emphasis / space ` in ` code

<!--MARKDOWNLINT-ENABLE -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!--  markdownlint-disable MD010-->

hard	tab / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-ENABLE  MD010  -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable MD010 MD038 -->

hard	tab / space * in * emphasis {MD037} / space ` in ` code

<!-- MARKDOWNLINT-enable  MD010  MD038  -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

before <!-- markdownlint-disable MD010 --> <!-- markdownlint-disable MD038 --> after

hard	tab / space * in * emphasis {MD037} / space ` in ` code

before<!-- markdownlint-enable MD010 --><!-- markdownlint-enable MD038 -->after

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable hard_tab code -->

hard	tab / space * in * emphasis {MD037} / space ` in ` code

<!-- markdownlint-enable whitespace -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

hard	tab {MD010} <!-- markdownlint-disable --> <!-- markdownlint-enable -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

hard	tab <!-- markdownlint-disable md010 -->
<!-- markdownlint-enable md010 -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-enable -->
hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}
<!-- markdownlint-disable -->
<!-- markdownlint-disable -->
hard	tab / space * in * emphasis / space ` in ` code
<!-- markdownlint-enable -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

<!-- markdownlint-disable NotATag no-space-in-code -->
hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code
<!-- markdownlint-enable NotATag nO-sPaCe-In-CoDe -->

hard	tab {MD010} / space * in * emphasis {MD037} / space ` in ` code {MD038}

embedded <b>{MD033}</b> HTML
